# Script 2. Analyses of decomposability scores

Jacolien van Rij, May 2019

Supplementary materials for the paper: Simone A. Sprenger, Amélie la Roi, and Jacolien van Rij, The Development of Idiom Knowledge across the Life Span. May 2019. Under review.


---

## Packages and data

```r
library(plyr) 
library(itsadug)
library(mgcv)
library(plotfunctions)
```

The decomposability ratings are available for download [here](./Data).

```r
load("Data/Decomposability.rda")
```

---
## Analysis I: Familiarity

```r
# binomial data:
dat$fam <- ifelse(dat$Familiarity=="familiar", 0,1)

# logistic GAM with nonlinear trend for LogFreq:
m0 <- bam(fam ~ s(LogFreq)
          + s(Item, bs='re') 
          + s(Subject, bs='re')
          , data=dat, family='binomial', method='ML')

# logistic GAMM without logFreq:
m1 <- bam(fam ~ s(Item, bs='re') 
          +  s(Subject, bs='re')
          , data=dat, family='binomial', method='ML')

# note: model comparisons less reliable for binomial data
# therefore we use summary statistics:
summary(m0)

# Family: binomial 
# Link function: logit 
# 
# Formula:
# fam ~ s(LogFreq) + s(Item, bs = "re") + s(Subject, bs = "re")
# 
# Parametric coefficients:
#             Estimate Std. Error z value Pr(>|z|)    
# (Intercept)  -2.8751     0.2761  -10.41   <2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Approximate significance of smooth terms:
#                edf  Ref.df  Chi.sq  p-value    
# s(LogFreq)   1.001   1.001   50.35 1.30e-12 ***
# s(Item)    133.244 192.000 1630.94  < 2e-16 ***
# s(Subject)  28.876  33.000  665.30 5.16e-09 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# R-sq.(adj) =  0.538   Deviance explained = 55.1%
# -ML = 3779.4  Scale est. = 1         n = 3084


report_stats(m0)

#   smooth.term                          report
# 1  s(LogFreq)     Chi.sq(1.001)=50.35; p<.001
# 2     s(Item) Chi.sq(133.244)=1630.94; p<.001
# 3  s(Subject)   Chi.sq(28.876)=665.30; p<.001


AIC(m0, m1)

#          df      AIC
# m0 165.0874 1564.827
# m1 175.3897 1584.999


compareML(m0, m1)

# m0: fam ~ s(LogFreq) + s(Item, bs = "re") + s(Subject, bs = "re")
# 
# m1: fam ~ s(Item, bs = "re") + s(Subject, bs = "re")
# 
# Chi-square test of ML scores
# -----
#   Model    Score Edf Difference    Df   p.value Sig.
# 1    m1 3802.511   3                                
# 2    m0 3779.412   5     23.099 2.000 9.291e-11  ***
# 
# AIC difference: -20.17, model m0 has lower AIC.
```


---
## Analysis II: Decomposability Score

```r
# only data with rating:
dat2 <- droplevels(dat[!is.na(dat$Score),])
range(table(dat2$Item))
# [1]  2 49

## A. comparing random effects:

m1 <- bam(Score ~ s(LogFreq) + s(Item, bs='re') 
          + s(LogFreq, Subject, bs='fs', m=1),
          data=dat2, family=ocat(R=5), discrete = TRUE)

m2 <- bam(Score ~ s(LogFreq) + s(Item, bs='re') 
          + s(Subject, bs='re'),
          data=dat2, family=ocat(R=5), discrete = TRUE)

compareML(m1, m2)

# m1: Score ~ s(LogFreq) + s(Item, bs = "re") + s(LogFreq, Subject, 
#     bs = "fs", m = 1)
# 
# m2: Score ~ s(LogFreq) + s(Item, bs = "re") + s(Subject, bs = "re")
# 
# Chi-square test of fREML scores
# -----
#   Model    Score Edf Difference    Df p.value Sig.
# 1    m2 5900.548   5                              
# 2    m1 5899.722   6      0.826 1.000   0.199     
# 
# AIC difference: -1.59, model m1 has lower AIC.

## B. comparing fixed effects:

m3 <- bam(Score ~ s(LogFreq) + s(Item, bs='re') 
          + s(Subject, bs='re'),
          data=dat2, family=ocat(R=5), method="ML")
          
m4 <- bam(Score ~ s(Item, bs='re') 
          + s(Subject, bs='re'),
          data=dat2, family=ocat(R=5), method="ML")
          
# Model comparison:
AIC(m3, m4)

#          df      AIC
# m3 201.8727 6760.634
# m4 201.8706 6761.365


compareML(m3, m4)

# m3: Score ~ s(LogFreq) + s(Item, bs = "re") + s(Subject, bs = "re")
# 
# m4: Score ~ s(Item, bs = "re") + s(Subject, bs = "re")
# 
# Model m4 preferred: lower ML score (3.889), and lower df (2.000).
# -----
#   Model    Score Edf Difference    Df
# 1    m3 5153.305   5                 
# 2    m4 5149.416   3     -3.889 2.000
# 
# AIC difference: -0.73, model m3 has lower AIC.
# 
# Warning message:
# In compareML(m3, m4) : Only small difference in ML...

# Summary statistics:
summary(m3)

# Family: Ordered Categorical(-1,0.64,1.83,3.52) 
# Link function: identity 
# 
# Formula:
# Score ~ s(LogFreq) + s(Item, bs = "re") + s(Subject, bs = "re")
# 
# Parametric coefficients:
#             Estimate Std. Error t value Pr(>|t|)   
# (Intercept)   0.5937     0.1996   2.975  0.00296 **
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Approximate significance of smooth terms:
#                edf  Ref.df      F  p-value    
# s(LogFreq)   1.001   1.001  2.690    0.101    
# s(Item)    164.393 191.000  9.231 8.13e-11 ***
# s(Subject)  30.992  33.000 26.643 1.98e-06 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# Deviance explained = 99.5%
# -ML = 5153.3  Scale est. = 1         n = 2579

report_stats(m3)

#   smooth.term                            report
# 1  s(LogFreq)  F(1.001, 2381.614)=2.69; p=0.101
# 2     s(Item) F(164.393, 2381.614)=9.23; p<.001
# 3  s(Subject) F(30.992, 2381.614)=26.64; p<.001
```



